@@ -188,8 +188,9 @@ class Store:
 
     LOCAL_RESOURCES = (
         'Cargo.toml', 'main.go', 'go.mod', 'main.rs', '.npmignore',
-        'package.json', 'pre_commit_placeholder_package.gemspec', 'setup.py',
-        'environment.yml', 'Makefile.PL',
+        'package.json', 'pre-commit-package-dev-1.rockspec',
+        'pre_commit_placeholder_package.gemspec', 'setup.py',
+        'environment.yml', 'Makefile.PL', 'pubspec.yaml',
         'renv.lock', 'renv/activate.R', 'renv/LICENSE.renv',
     )
 
